abcd_specs_examples: Simple example datasets for ABCD's

Description Usage Format Details

Description

This are three (nested) datasets illustrating the logic model of change for a simple condom use intervention in a way that can be visualised using the abcd function. The full dataset is abcd_specs_full, a subset that does not explicitly include the conditions for effectiveness (instead showing letters that can then be explained in, for example, the manuscript text) is called abcd_specs_without_conditions, and a version that only contains the information about one sub-behavior (performance objective) is available as abcd_specs_single_po_without_conditions. The variables in the full dataset are:

Usage

1

Format

For abcd_specs_complete, a data frame with 7 variables and 7 rows; for abcd_specs_without_conditions, a data frame with 6 variables and 7 rows; for abcd_specs_single_po_without_conditions, a data frame with 5 variables and 4 rows;

Details

In addition to these three datasets, a Dutch example specification is included named abcd_specs_dutch_xtc.


academy-of-behavior-change/behaviorchange documentation built on May 12, 2019, 4:35 a.m.