Description Usage Arguments Value Examples
Apply multiple DiagrammeR global graph attributes
1 | apply_graph_theme(graph, ...)
|
graph |
The DiagrammeR::DiagrammeR graph to apply the attributes to. |
... |
One or more character vectors of length three, where the first element is
the attribute, the second the value, and the third, the attribute type ( |
The DiagrammeR::DiagrammeR graph.
1 2 3 4 | abcd_complete <- behaviorchange::abcd(behaviorchange::abcd_specs_complete)$output$graph;
abcd_complete <- apply_graph_theme(abcd_complete,
c("penwidth", 5, "node"),
c("penwidth", 15, "edge"));
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.