Description Details Author(s) See Also
Contains specialised analyses and visualisation tools for behavior change science. These facilitate conducting determinant studies (for example, using confidence interval-based estimation of relevance, CIBER, or CIBERlite plots), systematically developing, reporting, and analysing interventions (for example, using acyclic behavior change diagrams or ABCDs), and reporting about intervention effectiveness (for example, using the Numbers Needed for Change). This package is especially useful for researchers in the field of behavior change or health psychology and to behavior change professionals such as intervention developers and prevention workers.
Contains specialised analyses and visualisation tools for behavior change science. These facilitate conducting determinant studies (for example, using confidence interval-based estimation of relevance, CIBER, or CIBERlite plots), systematically developing, reporting, and analysing interventions (for example, using acyclic behavior change diagrams), and reporting about intervention effectiveness (for example, using the Numbers Needed for Change). This package is especially useful for researchers in the field of behavior change or health psychology and to behavior change professionals such as intervention developers and prevention workers.
Maintainer: Gjalt-Jorn Peters gjalt-jorn@a-bc.eu [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.