Description Usage Arguments Details Value References See Also Examples
These functions are used in conjunction with the
determinantStructure family of funtions to conveniently work
with determinant structures.
1 2 3 4 5 6 7 8 9 10 11 | detStructAddVarLabels(determinantStructure, varLabelDf,
varNameCol = "varNames.cln", leftAnchorCol = "leftAnchors",
rightAnchorCol = "rightAnchors", subQuestionCol = "subQuestions",
questionTextCol = "questionText")
detStructAddVarNames(determinantStructure, names)
detStructComputeProducts(determinantStructure, data, append = TRUE)
detStructComputeScales(determinantStructure, data, append = TRUE,
separator = "_")
|
determinantStructure |
The |
varLabelDf |
The variable label dataframe as generated by
|
varNameCol |
The name of the column of the |
leftAnchorCol |
The name of the column of the |
rightAnchorCol |
The name of the column of the |
subQuestionCol |
The name of the column of the |
questionTextCol |
The name of the column of the |
names |
A character vector with the variable names. These are matched
against the regular expressions as specified in the
|
data |
The dataframe containing the data; the variables names specified
in |
append |
Whether to only return the products or scales, or whether to append these to the dataframe and return the entire dataframe. |
separator |
The separator to use when constructing the scale variables names. |
This family of functions will be explained more in detail in a forthcoming paper.
detStructAddVarLabels and detStructAddVarNames just
change the determinantStructure object;
detStructComputeProducts and detStructComputeScales return
either the dataframe with the new variables appended (if append =
TRUE) or just a dataframe with the new variables (if append =
FALSE).
(Forthcoming)
determinantStructure, determinantVar,
subdeterminants, subdeterminantProducts,
detStructCIBER
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 | ### Create some bogus determinant data
detStudy <- mtcars[, c(1, 3:7)];
names(detStudy) <- c('rUse_behav',
'rUse_intention',
'rUse_attitude1',
'rUse_attitude2',
'rUse_expAtt1',
'rUse_expAtt2');
### Specify the determinant structure
### First a subdeterminant
expAtt <-
behaviorchange::subdeterminants("Subdeterminants",
"expAtt");
### Then two determinants
attitude <-
behaviorchange::determinantVar("Determinant",
"attitude",
expAtt);
intention <-
behaviorchange::determinantVar("ProximalDeterminant",
"intention",
attitude);
### Then the entire determinant strcture
detStruct <-
behaviorchange::determinantStructure('Behavior',
list('behav',
behaviorRegEx = 'rUse'),
intention);
### Add the variable names
behaviorchange::detStructAddVarNames(detStruct,
names(detStudy));
### Add the determinant scale variable to the dataframe
detStudyPlus <-
behaviorchange::detStructComputeScales(detStruct,
data=detStudy);
### Show its presence
names(detStudyPlus);
mean(detStudyPlus$rUse_Determinant);
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.